searchNodes=[{"doc":"The Gettext module provides a gettext-based API for working with internationalized applications.Using GettextTo use Gettext, a module that calls use Gettext has to be defined:defmodule MyApp.Gettext do use Gettext, otp_app: :my_app endThis automatically defines some macros in the MyApp.Gettext module. Here are some examples:import MyApp.Gettext # Simple translation gettext(&quot;Here is the string to translate&quot;) # Plural translation ngettext( &quot;Here is the string to translate&quot;, &quot;Here are the strings to translate&quot;, 3 ) # Domain-based translation dgettext(&quot;errors&quot;, &quot;Here is the error message to translate&quot;) # Context-based translation pgettext(&quot;email&quot;, &quot;Email text to translate&quot;) # All of the above dpngettext( &quot;errors&quot;, &quot;context&quot;, &quot;Here is the string to translate&quot;, &quot;Here are the strings to translate&quot;, 3 )The arguments for the Gettext macros and their order can be derived from their names. For dpgettext/4 the arguments are: domain, context, msgid, bindings (default to %{}).Translations are looked up from .po files. In the following sections we will explore exactly what are those files before we explore the &quot;Gettext API&quot; in detail.TranslationsTranslations are stored inside PO (Portable Object) files, with a .po extension. For example, this is a snippet from a PO file:# This is a comment msgid &quot;Hello world!&quot; msgstr &quot;Ciao mondo!&quot;PO files containing translations for an application must be stored in a directory (by default it's priv/gettext) that has the following structure:gettext directory └─ locale └─ LC_MESSAGES ├─ domain_1.po ├─ domain_2.po └─ domain_3.poHere, locale is the locale of the translations (for example, en_US), LC_MESSAGES is a fixed directory, and domain_i.po are PO files containing domain-scoped translations. For more information on domains, check out the &quot;Domains&quot; section below.A concrete example of such a directory structure could look like this:priv/gettext └─ en_US | └─ LC_MESSAGES | ├─ default.po | └─ errors.po └─ it └─ LC_MESSAGES ├─ default.po └─ errors.poBy default, Gettext expects translations to be stored under the priv/gettext directory of an application. This behaviour can be changed by specifying a :priv option when using Gettext:# Look for translations in my_app/priv/translations instead of # my_app/priv/gettext use Gettext, otp_app: :my_app, priv: &quot;priv/translations&quot;The translations directory specified by the :priv option should be a directory inside priv/, otherwise some things (like mix compile.gettext) won't work as expected.LocaleAt runtime, all gettext-related functions and macros that do not explicitly take a locale as an argument read the locale from the backend locale and fallbacks to Gettext's locale.Gettext.put_locale/1 can be used to change the locale of all backends for the current Elixir process. That's the preferred mechanism for setting the locale at runtime. Gettext.put_locale/2 can be used when you want to set the locale of one specific Gettext backend without affecting other Gettext backends.Similarly, Gettext.get_locale/0 gets the locale for all backends in the current process. Gettext.get_locale/1 gets the locale of a specific backend for the current process. Check their documentation for more information.Locales are expressed as strings (like &quot;en&quot; or &quot;fr&quot;); they can be arbitrary strings as long as they match a directory name. As mentioned above, the locale is stored per-process (in the process dictionary): this means that the locale must be set in every new process in order to have the right locale available for that process. Pay attention to this behaviour, since not setting the locale will not result in any errors when Gettext.get_locale/0 or Gettext.get_locale/1 are called; the default locale will be returned instead.To decide which locale to use, each gettext-related function in a given backend follows these steps:if there is a backend-specific locale for the given backend for this process (see put_locale/2), use that, otherwiseif there is a global locale for this process (see put_locale/1), use that, otherwiseif there is a backend-specific default locale in the configuration for that backend's :otp_app (see the &quot;Default locale&quot; section below), use that, otherwiseuse the default global Gettext locale (see the &quot;Default locale&quot; section below)Default localeThe global Gettext default locale can be configured through the :default_locale key of the :gettext application:config :gettext, :default_locale, &quot;fr&quot;By default the global locale is &quot;en&quot;. See also get_locale/0 and put_locale/1.If for some reason a backend requires a different :default_locale than all other backends, you can set the :default_locale inside the backend configuration, but this approach is generally discouraged as it makes it hard to track which locale each backend is using:config :my_app, MyApp.Gettext, default_locale: &quot;fr&quot;Gettext APIThere are two ways to use Gettext:using macros from your own Gettext module, like MyApp.Gettextusing functions from the Gettext moduleThese two approaches are different and each one has its own use case.Using macrosEach module that calls use Gettext is usually referred to as a &quot;Gettext backend&quot;, as it implements the Gettext.Backend behaviour. When a module calls use Gettext, the following macros are automatically defined inside it:gettext/2dgettext/3pgettext/3dpgettext/4ngettext/4dngettext/5pngettext/5dpngettext/6all macros above with a _noop suffix (and without accepting bindings), for example pgettext_noop/2Supposing the caller module is MyApp.Gettext, the macros mentioned above behave as follows:gettext(msgid, bindings \\\\ %{}) - like Gettext.gettext(MyApp.Gettext, msgid, bindings)dgettext(domain, msgid, bindings \\\\ %{}) - like Gettext.dgettext(MyApp.Gettext, domain, msgid, bindings)pgettext(msgctxt, msgid, bindings \\\\ %{}) - like Gettext.pgettext(MyApp.Gettext, msgctxt, msgid, bindings)dpgettext(domain, msgctxt, msgid, bindings \\\\ %{}) - like Gettext.dpgettext(MyApp.Gettext, domain, msgctxt, msgid, bindings)ngettext(msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.ngettext(MyApp.Gettext, msgid, msgid_plural, n, bindings)dngettext(domain, msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.dngettext(MyApp.Gettext, domain, msgid, msgid_plural, n, bindings)pngettext(msgctxt, msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.pngettext(MyApp.Gettext, msgctxt, msgid, msgid_plural, n, bindings)dpngettext(domain, msgctxt, msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.dpngettext(MyApp.Gettext, domain, msgctxt, msgid, msgid_plural, n, bindings)*_noop family of functions - used to mark translations for extraction without translating them. See the documentation for these macros in Gettext.BackendSee also the Gettext.Backend behaviour for more detailed documentation about these macros.Using macros is preferred as Gettext is able to automatically sync the translations in your code with PO files. This, however, imposes a constraint: arguments passed to any of these macros have to be strings at compile time. This means that they have to be string literals or something that expands to a string literal at compile time (for example, a module attribute like @my_string &quot;foo&quot;).These are all valid uses of the Gettext macros:Gettext.put_locale(MyApp.Gettext, &quot;it&quot;) MyApp.Gettext.gettext(&quot;Hello world&quot;) #=&gt; &quot;Ciao mondo&quot; @msgid &quot;Hello world&quot; MyApp.Gettext.gettext(@msgid) #=&gt; &quot;Ciao mondo&quot;The *gettext macros raise an ArgumentError exception if they receive a domain, msgctxt, msgid, or msgid_plural that doesn't expand to a string at compile time:msgid = &quot;Hello world&quot; MyApp.Gettext.gettext(msgid) #=&gt; ** (ArgumentError) msgid must be a string literalUsing compile-time strings isn't always possible. For this reason, the Gettext module provides a set of functions as well.Using functionsIf compile-time strings cannot be used, the solution is to use the functions in the Gettext module instead of the macros described above. These functions perfectly mirror the macro API, but they all expect a module name as the first argument. This module has to be a module which calls use Gettext. For example:defmodule MyApp.Gettext do use Gettext, otp_app: :my_app end Gettext.put_locale(MyApp.Gettext, &quot;pt_BR&quot;) msgid = &quot;Hello world&quot; Gettext.gettext(MyApp.Gettext, msgid) #=&gt; &quot;Olá mundo&quot;While using functions from the Gettext module yields the same results as using macros (with the added benefit of dynamic arguments), all the compile-time features mentioned in the previous section are lost.DomainsThe dgettext and dngettext functions/macros also accept a domain as one of the arguments. The domain of a translation is determined by the name of the PO file that contains that translation. For example, the domain of translations in the it/LC_MESSAGES/errors.po file is &quot;errors&quot;, so those translations would need to be retrieved with dgettext or dngettext:MyApp.Gettext.dgettext(&quot;errors&quot;, &quot;Error!&quot;) #=&gt; &quot;Errore!&quot;When gettext or ngettext are used, the &quot;default&quot; domain is used.ContextsThe GNU Gettext implementation supports contexts, which are a way to contextualize translations. For example, in English, the word &quot;file&quot; could be used both as a noun as well as a verb. Contexts can be used to solve similar problems: you could have a imperative_verbs context and a nouns context as to avoid ambiguity. The functions that handle contexts have a p in their name (to match the GNU Gettext API), and are pgettext, dpgettext, pngettext, and dpngettext. The &quot;p&quot; stands for &quot;particular&quot;.InterpolationAll *gettext functions and macros provided by Gettext support interpolation. Interpolation keys can be placed in msgids or msgid_plurals with by enclosing them in %{ and }, like this:&quot;This is an %{interpolated} string&quot;Interpolation bindings can be passed as an argument to all of the *gettext functions/macros. For example, given the following PO file for the &quot;it&quot; locale:msgid &quot;Hello, %{name}!&quot; msgstr &quot;Ciao, %{name}!&quot;interpolation can be done like follows:Gettext.put_locale(MyApp.Gettext, &quot;it&quot;) MyApp.Gettext.gettext(&quot;Hello, %{name}!&quot;, name: &quot;Meg&quot;) #=&gt; &quot;Ciao, Meg!&quot;Interpolation keys that are in a string but not in the provided bindings result in a Gettext.Error exception:MyApp.Gettext.gettext(&quot;Hello, %{name}!&quot;) #=&gt; ** (Gettext.Error) missing interpolation keys: nameKeys that are in the interpolation bindings but that don't occur in the string are ignored. Interpolations in Gettext are often expanded at compile time, ensuring a low performance cost when running them at runtime.PluralizationPluralization in Gettext for Elixir works very similar to how pluralization works in GNU Gettext. The *ngettext functions/macros accept a msgid, a msgid_plural and a count of elements; the right translation is chosen based on the pluralization rule for the given locale.For example, given the following snippet of PO file for the &quot;it&quot; locale:msgid &quot;One error&quot; msgid_plural &quot;%{count} errors&quot; msgstr[0] &quot;Un errore&quot; msgstr[1] &quot;%{count} errori&quot;the ngettext macro can be used like this:Gettext.put_locale(MyApp.Gettext, &quot;it&quot;) MyApp.Gettext.ngettext(&quot;One error&quot;, &quot;%{count} errors&quot;, 3) #=&gt; &quot;3 errori&quot;The %{count} interpolation key is a special key since it gets replaced by the number of elements argument passed to *ngettext, like if the count: 3 key-value pair were in the interpolation bindings. Hence, never pass the count key in the bindings:# `count: 4` is ignored here MyApp.Gettext.ngettext(&quot;One error&quot;, &quot;%{count} errors&quot;, 3, count: 4) #=&gt; &quot;3 errori&quot;You can specify a &quot;pluralizer&quot; module via the :plural_forms option in the configuration for each Gettext backend.defmodule MyApp.Gettext do use Gettext, otp_app: :my_app, plural_forms: MyApp.PluralForms endTo learn more about pluralization rules, plural forms and what they mean to Gettext check the documentation for Gettext.Plural.Missing translationsWhen a translation is missing in the specified locale (both with functions as well as with macros), the argument is returned:in case of calls to gettext/dgettext/pgettext/dpgettext, the msgid argument is returned as is;in case of calls to ngettext/dngettext/pngettext/dpngettext, the msgid argument is returned in case of a singular value and the msgid_plural is returned in case of a plural value (following the English pluralization rule).For example:Gettext.put_locale(MyApp.Gettext, &quot;foo&quot;) MyApp.Gettext.gettext(&quot;Hey there&quot;) #=&gt; &quot;Hey there&quot; MyApp.Gettext.ngettext(&quot;One error&quot;, &quot;%{count} errors&quot;, 3) #=&gt; &quot;3 errors&quot;Empty translationsWhen a msgstr is empty (&quot;&quot;), the translation is considered missing and the behaviour described above for missing translation is applied. A plural translation is considered to have an empty msgstr if at least one translation in the msgstr is empty.Compile-time featuresAs mentioned above, using the Gettext macros (as opposed to functions) allows Gettext to operate on those translations at compile-time. This can be used to extract translations from the source code into POT files automatically (instead of having to manually add translations to POT files when they're added to the source code). The gettext.extract does exactly this: whenever there are new translations in the source code, running gettext.extract syncs the existing POT files with the changed code base. Read the documentation for Mix.Tasks.Gettext.Extract for more information on the extraction process.POT files are just template files and the translations in them do not actually contain translated strings. A POT file looks like this:# The msgstr is empty msgid &quot;hello, world&quot; msgstr &quot;&quot;Whenever a POT file changes, it's likely that developers (or translators) will want to update the corresponding PO files for each locale. To do that, gettext provides the gettext.merge Mix task. For example, running:mix gettext.merge priv/gettext --locale pt_BRwill update all the PO files in priv/gettext/pt_BR/LC_MESSAGES with the new version of the POT files in priv/gettext. Read more about the merging process in the documentation for Mix.Tasks.Gettext.Merge.Finally, Gettext is able to recompile modules that call use Gettext whenever PO files change. To enable this feature, the :gettext compiler needs to be added to the list of Mix compilers. In mix.exs:def project do [compilers: [:gettext] ++ Mix.compilers] endConfiguration:gettext configurationThe :gettext application supports the following configuration options::default_locale - a string which specifies the default global Gettext locale to use for all backends. See the &quot;Locale&quot; section for more information on backend-specific, global, and default locales.Backend configurationA Gettext backend supports some options to be configured. These options can be configured in two ways: either by passing them to use Gettext (hence at compile time):defmodule MyApp.Gettext do use Gettext, options endor by using Mix configuration, configuring the key corresponding to the backend in the configuration for your application:# For example, in config/config.exs config :my_app, MyApp.Gettext, optionsNote that the :otp_app option (an atom representing an OTP application) has to always be present and has to be passed to use Gettext because it's used to determine the application to read the configuration of (:my_app in the example above); for this reason, :otp_app can't be configured via the Mix configuration. This option is also used to determine the application's directory where to search translations in.The following is a comprehensive list of supported options::priv - a string representing a directory where translations will be searched. The directory is relative to the directory of the application specified by the :otp_app option. It is recommended to always have this directory inside &quot;priv&quot;, otherwise some features like the &quot;mix compile.gettext&quot; won't work as expected. By default it's &quot;priv/gettext&quot;.:plural_forms - a module which will act as a &quot;pluralizer&quot;. For more information, look at the documentation for Gettext.Plural.:default_locale - a string which specifies the default locale to use for the given backend.:one_module_per_locale - instead of bundling all locales into a single module, this option makes Gettext build one internal module per locale. This reduces compilation times and beam file sizes for large projects. This option requires Elixir v1.6.:allowed_locales - a list of locales to bundle in the backend. Defaults to all the locales discovered in the :priv directory. This option can be useful in development to reduce compile-time by compiling only a subset of all available locales.Mix tasks configurationYou can configure Gettext Mix tasks under the :gettext key in the configuration returned by project/0 in mix.exs:def project() do [app: :my_app, # ... gettext: [...]] endThe following is a list of the supported configuration options::fuzzy_threshold - the default threshold for the Jaro distance measuring the similarity of translations. Look at the documentation for the mix gettext.merge task (Mix.Tasks.Gettext.Merge) for more information on fuzzy translations.:excluded_refs_from_purging - a regex that is matched against translation references. Gettext will preserve all translations in all POT files that have a matching reference. You can use this pattern to prevent Gettext from removing translations that you have extracted using another tool.:compiler_po_wildcard - a binary that specifies the wildcard that the :gettext compiler will use to find changed PO files in order to recompile their respective Gettext backends. This wildcard has to be relative to the &quot;priv&quot; directory of your application. Defaults to &quot;gettext/*/LC_MESSAGES/*.po&quot;.:write_reference_comments - a boolean that specifies whether reference comments should be written when outputting PO(T) files. If this is false, reference comments will not be written when extracting translations or merging translations, and the ones already found in files will be discarded.:sort_by_msgid - a boolean that modifies the sorting behavior. By default, the order of existing translations in a POT file is kept and new translations are appended to the file. If :sort_by_msgid is set to true, existing and new translations will be mixed and sorted alphabetically by msgid.","ref":"Gettext.html","title":"Gettext","type":"module"},{"doc":"Returns the translation of the given string in the given domain.The string is translated by the backend module.The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module.If the translation for the given msgid is not found, the msgid (interpolated if necessary) is returned.Examplesdefmodule MyApp.Gettext do use Gettext, otp_app: :my_app end Gettext.put_locale(MyApp.Gettext, &quot;it&quot;) Gettext.dgettext(MyApp.Gettext, &quot;errors&quot;, &quot;Invalid&quot;) #=&gt; &quot;Non valido&quot; Gettext.dgettext(MyApp.Gettext, &quot;errors&quot;, &quot;%{name} is not a valid name&quot;, name: &quot;Meg&quot;) #=&gt; &quot;Meg non è un nome valido&quot; Gettext.dgettext(MyApp.Gettext, &quot;alerts&quot;, &quot;nonexisting&quot;) #=&gt; &quot;nonexisting&quot;","ref":"Gettext.html#dgettext/4","title":"Gettext.dgettext/4","type":"function"},{"doc":"Returns the pluralized translation of the given string in the given domain.The string is translated and pluralized by the backend module.The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module.If the translation for the given msgid and msgid_plural is not found, the msgid or msgid_plural (based on n being singular or plural) is returned (interpolated if necessary).Examplesdefmodule MyApp.Gettext do use Gettext, otp_app: :my_app end Gettext.dngettext(MyApp.Gettext, &quot;errors&quot;, &quot;Error&quot;, &quot;%{count} errors&quot;, 3) #=&gt; &quot;3 errori&quot; Gettext.dngettext(MyApp.Gettext, &quot;errors&quot;, &quot;Error&quot;, &quot;%{count} errors&quot;, 1) #=&gt; &quot;Errore&quot;","ref":"Gettext.html#dngettext/6","title":"Gettext.dngettext/6","type":"function"},{"doc":"Returns the translation of the given string with a given context in the given domain.The string is translated by the backend module.The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module.If the translation for the given msgid is not found, the msgid (interpolated if necessary) is returned.Examplesdefmodule MyApp.Gettext do use Gettext, otp_app: :my_app end Gettext.put_locale(MyApp.Gettext, &quot;it&quot;) Gettext.dpgettext(MyApp.Gettext, &quot;errors&quot;, &quot;user error&quot;, &quot;Invalid&quot;) #=&gt; &quot;Non valido&quot; Gettext.dgettext(MyApp.Gettext, &quot;errors&quot;, &quot;signup form&quot;, &quot;%{name} is not a valid name&quot;, name: &quot;Meg&quot;) #=&gt; &quot;Meg non è un nome valido&quot;","ref":"Gettext.html#dpgettext/5","title":"Gettext.dpgettext/5","type":"function"},{"doc":"Returns the pluralized translation of the given string with a given context in the given domain.The string is translated and pluralized by the backend module.The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module.If the translation for the given msgid and msgid_plural is not found, the msgid or msgid_plural (based on n being singular or plural) is returned (interpolated if necessary).Examplesdefmodule MyApp.Gettext do use Gettext, otp_app: :my_app end Gettext.dpngettext(MyApp.Gettext, &quot;errors&quot;, &quot;user error&quot;, &quot;Error&quot;, &quot;%{count} errors&quot;, 3) #=&gt; &quot;3 errori&quot; Gettext.dpngettext(MyApp.Gettext, &quot;errors&quot;, &quot;user error&quot;, &quot;Error&quot;, &quot;%{count} errors&quot;, 1) #=&gt; &quot;Errore&quot;","ref":"Gettext.html#dpngettext/7","title":"Gettext.dpngettext/7","type":"function"},{"doc":"Gets the global Gettext locale for the current process.This function returns the value of the global Gettext locale for the current process. This global locale is shared between all Gettext backends; if you want backend-specific locales, see get_locale/1 and put_locale/2. If the global Gettext locale is not set, this function returns the default global locale (configurable in the configuration for the :gettext application, see the module documentation for more information).ExamplesGettext.get_locale() #=&gt; &quot;en&quot;","ref":"Gettext.html#get_locale/0","title":"Gettext.get_locale/0","type":"function"},{"doc":"Gets the locale for the current process and the given backend.This function returns the value of the locale for the current process and the given backend. If there is no locale for the current process and the given backend, then either the global Gettext locale (if set), or the default locale for the given backend, or the global default locale is returned. See the &quot;Locale&quot; section in the module documentation for more information.ExamplesGettext.get_locale(MyApp.Gettext) #=&gt; &quot;en&quot;","ref":"Gettext.html#get_locale/1","title":"Gettext.get_locale/1","type":"function"},{"doc":"Returns the translation of the given string in the &quot;default&quot; domain.Works exactly like:Gettext.dgettext(backend, &quot;default&quot;, msgid, bindings)","ref":"Gettext.html#gettext/3","title":"Gettext.gettext/3","type":"function"},{"doc":"Returns all the locales for which PO files exist for the given backend.If the translations directory for the given backend doesn't exist, then an empty list is returned.ExamplesWith the following backend:defmodule MyApp.Gettext do use Gettext, otp_app: :my_app endand the following translations directory:my_app/priv/gettext ├─ en ├─ it └─ pt_BRthen:Gettext.known_locales(MyApp.Gettext) #=&gt; [&quot;en&quot;, &quot;it&quot;, &quot;pt_BR&quot;]","ref":"Gettext.html#known_locales/1","title":"Gettext.known_locales/1","type":"function"},{"doc":"Returns the pluralized translation of the given string in the &quot;default&quot; domain.Works exactly like:Gettext.dngettext(backend, &quot;default&quot;, msgid, msgid_plural, n, bindings)","ref":"Gettext.html#ngettext/5","title":"Gettext.ngettext/5","type":"function"},{"doc":"Returns the translation of the given string with the given contextThe string is translated by the backend module.The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module.If the translation for the given msgid is not found, the msgid (interpolated if necessary) is returned.Examplesdefmodule MyApp.Gettext do use Gettext, otp_app: :my_app end Gettext.put_locale(MyApp.Gettext, &quot;it&quot;) Gettext.pgettext(MyApp.Gettext, &quot;user-interface&quot;, &quot;Invalid&quot;) #=&gt; &quot;Non valido&quot; Gettext.pgettext(MyApp.Gettext, &quot;user-interface&quot;, &quot;%{name} is not a valid name&quot;, name: &quot;Meg&quot;) #=&gt; &quot;Meg non è un nome valido&quot; Gettext.pgettext(MyApp.Gettext, &quot;alerts-users&quot;, &quot;nonexisting&quot;) #=&gt; &quot;nonexisting&quot;","ref":"Gettext.html#pgettext/4","title":"Gettext.pgettext/4","type":"function"},{"doc":"Returns the pluralized translation of the given string with a given context in the &quot;default&quot; domain.Works exactly like:Gettext.dpngettext(backend, &quot;default&quot;, context, msgid, msgid_plural, n, bindings)","ref":"Gettext.html#pngettext/6","title":"Gettext.pngettext/6","type":"function"},{"doc":"Sets the global Gettext locale for the current process.The locale is stored in the process dictionary. locale must be a string; if it's not, an ArgumentError exception is raised.ExamplesGettext.put_locale(&quot;pt_BR&quot;) #=&gt; nil Gettext.get_locale() #=&gt; &quot;pt_BR&quot;","ref":"Gettext.html#put_locale/1","title":"Gettext.put_locale/1","type":"function"},{"doc":"Sets the locale for the current process and the given backend.The locale is stored in the process dictionary. locale must be a string; if it's not, an ArgumentError exception is raised.ExamplesGettext.put_locale(MyApp.Gettext, &quot;pt_BR&quot;) #=&gt; nil Gettext.get_locale(MyApp.Gettext) #=&gt; &quot;pt_BR&quot;","ref":"Gettext.html#put_locale/2","title":"Gettext.put_locale/2","type":"function"},{"doc":"Runs fun with the global Gettext locale set to locale.This function just sets the global Gettext locale to locale before running fun and sets it back to its previous value afterwards. Note that put_locale/2 is used to set the locale, which is thus set only for the current process (keep this in mind if you plan on spawning processes inside fun).The value returned by this function is the return value of fun.ExamplesGettext.put_locale(&quot;fr&quot;) MyApp.Gettext.gettext(&quot;Hello world&quot;) #=&gt; &quot;Bonjour monde&quot; Gettext.with_locale(&quot;it&quot;, fn -&gt; MyApp.Gettext.gettext(&quot;Hello world&quot;) end) #=&gt; &quot;Ciao mondo&quot; MyApp.Gettext.gettext(&quot;Hello world&quot;) #=&gt; &quot;Bonjour monde&quot;","ref":"Gettext.html#with_locale/2","title":"Gettext.with_locale/2","type":"function"},{"doc":"Runs fun with the Gettext locale set to locale for the given backend.This function just sets the Gettext locale for backend to locale before running fun and sets it back to its previous value afterwards. Note that put_locale/2 is used to set the locale, which is thus set only for the current process (keep this in mind if you plan on spawning processes inside fun).The value returned by this function is the return value of fun.ExamplesGettext.put_locale(MyApp.Gettext, &quot;fr&quot;) MyApp.Gettext.gettext(&quot;Hello world&quot;) #=&gt; &quot;Bonjour monde&quot; Gettext.with_locale(MyApp.Gettext, &quot;it&quot;, fn -&gt; MyApp.Gettext.gettext(&quot;Hello world&quot;) end) #=&gt; &quot;Ciao mondo&quot; MyApp.Gettext.gettext(&quot;Hello world&quot;) #=&gt; &quot;Bonjour monde&quot;","ref":"Gettext.html#with_locale/3","title":"Gettext.with_locale/3","type":"function"},{"doc":"","ref":"Gettext.html#t:backend/0","title":"Gettext.backend/0","type":"type"},{"doc":"","ref":"Gettext.html#t:bindings/0","title":"Gettext.bindings/0","type":"type"},{"doc":"","ref":"Gettext.html#t:locale/0","title":"Gettext.locale/0","type":"type"},{"doc":"Behaviour that defines the macros that a Gettext backend has to implement.","ref":"Gettext.Backend.html","title":"Gettext.Backend","type":"behaviour"},{"doc":"Same as dgettext(domain, msgid, %{}).See also Gettext.dgettext/4.","ref":"Gettext.Backend.html#c:dgettext/2","title":"Gettext.Backend.dgettext/2","type":"macrocallback"},{"doc":"Translates the given msgid in the given domain.bindings is a map of bindings to support interpolation.See also Gettext.dgettext/4.","ref":"Gettext.Backend.html#c:dgettext/3","title":"Gettext.Backend.dgettext/3","type":"macrocallback"},{"doc":"Marks the given translation for extraction and returns it unchanged.This macro can be used to mark a translation for extraction when mix gettext.extract is run. The return value is the given string, so that this macro can be used seamlessly in place of the string to extract.ExamplesMyApp.Gettext.dgettext_noop(&quot;errors&quot;, &quot;Error found!&quot;) #=&gt; &quot;Error found!&quot;","ref":"Gettext.Backend.html#c:dgettext_noop/2","title":"Gettext.Backend.dgettext_noop/2","type":"macrocallback"},{"doc":"Same as dngettext(domain, msgid, msgid_plural, n, %{}).See also Gettext.dngettext/6.","ref":"Gettext.Backend.html#c:dngettext/4","title":"Gettext.Backend.dngettext/4","type":"macrocallback"},{"doc":"Translates the given plural translation (msgid + msgid_plural) in the given domain.n is an integer used to determine how to pluralize the translation. bindings is a map of bindings to support interpolation.See also Gettext.dngettext/6.","ref":"Gettext.Backend.html#c:dngettext/5","title":"Gettext.Backend.dngettext/5","type":"macrocallback"},{"doc":"Marks the given translation for extraction and returns {msgid, msgid_plural}.This macro can be used to mark a translation for extraction when mix gettext.extract is run. The return value of this macro is {msgid, msgid_plural}.Examplesmy_fun = fn {msgid, msgid_plural} -&gt; # do something with msgid and msgid_plural end my_fun.(MyApp.Gettext.dngettext_noop(&quot;errors&quot;, &quot;One error&quot;, &quot;%{count} errors&quot;))","ref":"Gettext.Backend.html#c:dngettext_noop/3","title":"Gettext.Backend.dngettext_noop/3","type":"macrocallback"},{"doc":"Same as dpgettext(domain, msgid, %{}).See also Gettext.dpgettext/5.","ref":"Gettext.Backend.html#c:dpgettext/3","title":"Gettext.Backend.dpgettext/3","type":"macrocallback"},{"doc":"Translates the given msgid with a given context (msgctxt) in the given domain.bindings is a map of bindings to support interpolation.See also Gettext.dpgettext/5.","ref":"Gettext.Backend.html#c:dpgettext/4","title":"Gettext.Backend.dpgettext/4","type":"macrocallback"},{"doc":"Same as dpngettext(domain, msgctxt, msgid, msgid_plural, n, %{}).See also Gettext.dpngettext/7.","ref":"Gettext.Backend.html#c:dpngettext/5","title":"Gettext.Backend.dpngettext/5","type":"macrocallback"},{"doc":"Translates the given plural translation (msgid + msgid_plural) with the given context (msgctxt) in the given domain.n is an integer used to determine how to pluralize the translation. bindings is a map of bindings to support interpolation.See also Gettext.dpngettext/7.","ref":"Gettext.Backend.html#c:dpngettext/6","title":"Gettext.Backend.dpngettext/6","type":"macrocallback"},{"doc":"Same as gettext(msgid, %{}).See also Gettext.gettext/3.","ref":"Gettext.Backend.html#c:gettext/1","title":"Gettext.Backend.gettext/1","type":"macrocallback"},{"doc":"Same as dgettext(&quot;default&quot;, msgid, %{}).See also Gettext.gettext/3.","ref":"Gettext.Backend.html#c:gettext/2","title":"Gettext.Backend.gettext/2","type":"macrocallback"},{"doc":"Stores an &quot;extracted comment&quot; for the next translation.This macro can be used to add comments (Gettext refers to such comments as extracted comments) to the next translation that will be extracted. Extracted comments will be prefixed with #. in POT files.Calling this function multiple times will accumulate the comments; when another Gettext macro (such as gettext/2) is called, the comments will be extracted and attached to that translation, and they will be flushed so as to start again.This macro always returns :ok.ExamplesMyApp.Gettext.gettext_comment(&quot;The next translation is awesome&quot;) MyApp.Gettext.gettext_comment(&quot;Another comment for the next translation&quot;) MyApp.Gettext.gettext(&quot;The awesome translation&quot;)","ref":"Gettext.Backend.html#c:gettext_comment/1","title":"Gettext.Backend.gettext_comment/1","type":"macrocallback"},{"doc":"Same as dgettext_noop(&quot;default&quot;, msgid).","ref":"Gettext.Backend.html#c:gettext_noop/1","title":"Gettext.Backend.gettext_noop/1","type":"macrocallback"},{"doc":"Default handling for missing bindings.This function is called when there are missing bindings in a translation. It takes a Gettext.MissingBindingsError struct and the translation with the wrong bindings left as is with the %{} syntax.For example, if something like this is called:MyApp.Gettext.gettext(&quot;Hello %{name}, welcome to %{country}&quot;, name: &quot;Jane&quot;, country: &quot;Italy&quot;)and our it/LC_MESSAGES/default.po looks like this:msgid &quot;Hello %{name}, welcome to %{country}&quot; msgstr &quot;Ciao %{name}, benvenuto in %{cowntry}&quot; # (typo)then Gettext will call:MyApp.Gettext.handle_missing_bindings(exception, &quot;Ciao Jane, benvenuto in %{cowntry}&quot;)where exception is a struct that looks like this:%Gettext.MissingBindingsError{ backend: MyApp.Gettext, domain: &quot;default&quot;, locale: &quot;it&quot;, msgid: &quot;Hello %{name}, welcome to %{country}&quot;, bindings: [:country], }The return value of the handle_missing_bindings/2 callback is used as the translated string that the translation macros and functions return.The default implementation for this function uses Logger.error/1 to warn about the missing binding and returns the translated message with the incomplete bindings.This function can be overridden. For example, to raise when there are missing bindings:def handle_missing_bindings(exception, _incomplete) do raise exception end","ref":"Gettext.Backend.html#c:handle_missing_bindings/2","title":"Gettext.Backend.handle_missing_bindings/2","type":"callback"},{"doc":"Default handling for plural translations with a missing translation.Same as handle_missing_translation/4, but for plural translations. In this case, n is the number used for pluralizing the translated string.","ref":"Gettext.Backend.html#c:handle_missing_plural_translation/6","title":"Gettext.Backend.handle_missing_plural_translation/6","type":"callback"},{"doc":"Default handling for translations with a missing translation.When a Gettext function/macro is called with a string to translate into a locale but that locale doesn't provide a translation for that string, this callback is invoked. msgid is the string that Gettext tried to translate.This function should return {:ok, translated} if a translation can be fetched or constructed for the given string, or {:default, msgid} otherwise.","ref":"Gettext.Backend.html#c:handle_missing_translation/4","title":"Gettext.Backend.handle_missing_translation/4","type":"callback"},{"doc":"Same as ngettext(msgid, msgid_plural, n, %{}).See also Gettext.ngettext/5.","ref":"Gettext.Backend.html#c:ngettext/3","title":"Gettext.Backend.ngettext/3","type":"macrocallback"},{"doc":"Same as dngettext(&quot;default&quot;, msgid, msgid_plural, n, bindings).See also Gettext.ngettext/5.","ref":"Gettext.Backend.html#c:ngettext/4","title":"Gettext.Backend.ngettext/4","type":"macrocallback"},{"doc":"Same as dngettext_noop(&quot;default&quot;, msgid, mgsid_plural).","ref":"Gettext.Backend.html#c:ngettext_noop/2","title":"Gettext.Backend.ngettext_noop/2","type":"macrocallback"},{"doc":"Same as pgettext(msgctxt, msgid, %{}).See also Gettext.pgettext/4.","ref":"Gettext.Backend.html#c:pgettext/2","title":"Gettext.Backend.pgettext/2","type":"macrocallback"},{"doc":"Translates the given msgid with the given context (msgctxt).bindings is a map of bindings to support interpolation.See also Gettext.pgettext/4.","ref":"Gettext.Backend.html#c:pgettext/3","title":"Gettext.Backend.pgettext/3","type":"macrocallback"},{"doc":"Same as pngettext(msgctxt, msgid, msgid_plural, n, %{}).See also Gettext.pngettext/6.","ref":"Gettext.Backend.html#c:pngettext/4","title":"Gettext.Backend.pngettext/4","type":"macrocallback"},{"doc":"Translates the given plural translation (msgid + msgid_plural) with the given context (msgctxt).n is an integer used to determine how to pluralize the translation. bindings is a map of bindings to support interpolation.See also Gettext.pngettext/6.","ref":"Gettext.Backend.html#c:pngettext/5","title":"Gettext.Backend.pngettext/5","type":"macrocallback"},{"doc":"This module provides facilities for working with PO (.po) and POT (.pot) files (mainly parsing).","ref":"Gettext.PO.html","title":"Gettext.PO","type":"module"},{"doc":"Dumps a Gettext.PO struct as iodata.This function dumps a Gettext.PO struct (representing a PO file) as iodata, which can later be written to a file or converted to a string with IO.iodata_to_binary/1.ExamplesAfter running the following code:iodata = Gettext.PO.dump %Gettext.PO{ headers: [&quot;Last-Translator: Jane Doe&quot;], translations: [ %Gettext.PO.Translation{msgid: &quot;foo&quot;, msgstr: &quot;bar&quot;, comments: &quot;# A comment&quot;} ] } File.write!(&quot;/tmp/test.po&quot;, iodata)the /tmp/test.po file would look like this:msgid &quot;&quot; msgstr &quot;&quot; &quot;Last-Translator: Jane Doe&quot; # A comment msgid &quot;foo&quot; msgstr &quot;bar&quot;","ref":"Gettext.PO.html#dump/2","title":"Gettext.PO.dump/2","type":"function"},{"doc":"Parses the contents of a file into a Gettext.PO struct.This function works similarly to parse_string/1 except that it takes a file and parses the contents of that file. It can return:{:ok, po}{:error, line, reason} if there is an error with the contents of the .po file (for example, a syntax error){:error, reason} if there is an error with reading the file (this error is one of the errors that can be returned by File.read/1)Examples{:ok, po} = Gettext.PO.parse_file &quot;translations.po&quot; po.file #=&gt; &quot;translations.po&quot; Gettext.PO.parse_file &quot;nonexistent&quot; #=&gt; {:error, :enoent}","ref":"Gettext.PO.html#parse_file/1","title":"Gettext.PO.parse_file/1","type":"function"},{"doc":"Parses the contents of a file into a Gettext.PO struct, raising if there are any errors.Works like parse_file/1, except that it raises a Gettext.PO.SyntaxError exception if there's a syntax error in the file or a File.Error error if there's an error with reading the file.ExamplesGettext.PO.parse_file! &quot;nonexistent.po&quot; #=&gt; ** (File.Error) could not parse &quot;nonexistent.po&quot;: no such file or directory","ref":"Gettext.PO.html#parse_file!/1","title":"Gettext.PO.parse_file!/1","type":"function"},{"doc":"Parses a string into a Gettext.PO struct.This function parses a given str into a Gettext.PO struct. It returns {:ok, po} if there are no errors, otherwise {:error, line, reason}.Examplesiex&gt; {:ok, po} = Gettext.PO.parse_string &quot;&quot;&quot; ...&gt; msgid &quot;foo&quot; ...&gt; msgstr &quot;bar&quot; ...&gt; &quot;&quot;&quot; iex&gt; [t] = po.translations iex&gt; t.msgid [&quot;foo&quot;] iex&gt; t.msgstr [&quot;bar&quot;] iex&gt; po.headers [] iex&gt; Gettext.PO.parse_string &quot;foo&quot; {:error, 1, &quot;unknown keyword &#39;foo&#39;&quot;}","ref":"Gettext.PO.html#parse_string/1","title":"Gettext.PO.parse_string/1","type":"function"},{"doc":"Parses a string into a Gettext.PO struct, raising an exception if there are any errors.Works exactly like parse_string/1, but returns a Gettext.PO struct if there are no errors or raises a Gettext.PO.SyntaxError error if there are.Examplesiex&gt; Gettext.PO.parse_string!(&quot;msgid&quot;) ** (Gettext.PO.SyntaxError) 1: no space after &#39;msgid&#39;","ref":"Gettext.PO.html#parse_string!/1","title":"Gettext.PO.parse_string!/1","type":"function"},{"doc":"","ref":"Gettext.PO.html#t:line/0","title":"Gettext.PO.line/0","type":"type"},{"doc":"","ref":"Gettext.PO.html#t:parse_error/0","title":"Gettext.PO.parse_error/0","type":"type"},{"doc":"","ref":"Gettext.PO.html#t:t/0","title":"Gettext.PO.t/0","type":"type"},{"doc":"","ref":"Gettext.PO.html#t:translation/0","title":"Gettext.PO.translation/0","type":"type"},{"doc":"A struct that holds information on a plural translation.This struct describes a translation which has a plural form, such as the one in the following snippet of .po file:msgid &quot;There was an error&quot; msgid_plural &quot;There were %{count} errors&quot; msgstr[0] &quot;C&#39;è stato un errore&quot; msgstr[1] &quot;Ci sono stati %{count} errori&quot;This struct contains three fields:msgid - the id of the singular translation.msgid_plural - the id of the pluralized translation.msgstr - a map which maps plural forms as keys to translated strings as values. The plural forms mentioned here are the ones described in Gettext.Plural.comments - a list of comments as they are found in the PO file (for example, [&quot;# foo&quot;]).extracted_comments - a list of extracted comments (for example, [&quot;#. foo&quot;, &quot;#. bar&quot;]).references - a list of references (files this translation comes from) in the form {file, line}.flags - a set of flags for this translation.po_source_line - the line this translation is on in the PO file where it comes from.","ref":"Gettext.PO.PluralTranslation.html","title":"Gettext.PO.PluralTranslation","type":"module"},{"doc":"","ref":"Gettext.PO.PluralTranslation.html#t:t/0","title":"Gettext.PO.PluralTranslation.t/0","type":"type"},{"doc":"A struct that holds information on a translation.This struct describes a translation that has no plural form, such as the one in the following snippet of .po file:msgid &quot;Hello world!&quot; msgstr &quot;Ciao mondo!&quot;Translations with a plural form are not represented as Gettext.PO.Translation structs, but as Gettext.PO.PluralTranslation structs.This struct contains the following fields:msgid - the id of the translation.msgstr - the translated string.comments - a list of comments as they are found in the PO file (for example, [&quot;# foo&quot;]).extracted_comments - a list of extracted comments (for example, [&quot;#. foo&quot;, &quot;#. bar&quot;]).references - a list of references (files this translation comes from) in the form {file, line}.flags - a set of flags for this translation.po_source_line - the line this translation is on in the PO file where it comes from.","ref":"Gettext.PO.Translation.html","title":"Gettext.PO.Translation","type":"module"},{"doc":"","ref":"Gettext.PO.Translation.html#t:t/0","title":"Gettext.PO.Translation.t/0","type":"type"},{"doc":"Behaviour and default implementation for finding plural forms in given locales.This module both defines the Gettext.Plural behaviour and provides a default implementation for it.Plural formsFor a given language, there is a grammatical rule on how to change words depending on the number qualifying the word. Different languages can have different rules. [source]Such grammatical rules define a number of plural forms. For example, English has two plural forms: one for when there is just one element (the singular) and another one for when there are zero or more than one elements (the plural). There are languages which only have one plural form and there are languages which have more than two.In GNU Gettext (and in Gettext for Elixir), plural forms are represented by increasing 0-indexed integers. For example, in English 0 means singular and 1 means plural.The goal of this module is to determine, given a locale:how many plural forms exist in that locale (nplurals/1);to what plural form a given number of elements belongs to in that locale (plural/2).Default implementationGettext.Plural provides a default implementation of a plural module. Most languages used on Earth should be covered by this default implementation. If custom pluralization rules are needed (for example, to add additional languages) a different plural module can be specified when creating a Gettext backend. For example, pluralization rules for the Elvish language could be added as follows:defmodule MyApp.Plural do @behaviour Gettext.Plural def nplurals(&quot;elv&quot;), do: 3 def plural(&quot;elv&quot;, 0), do: 0 def plural(&quot;elv&quot;, 1), do: 1 def plural(&quot;elv&quot;, _), do: 2 # Fallback to Gettext.Plural def nplurals(locale), do: Gettext.Plural.nplurals(locale) def plural(locale, n), do: Gettext.Plural.plural(locale, n) end defmodule MyApp.Gettext do use Gettext, otp_app: :my_app, plural_forms: MyApp.Plural endThe mathematical expressions used in this module to determine the plural form of a given number of elements are taken from this page as well as from Mozilla's guide on &quot;Localization and plurals&quot;.Unknown localesTrying to call Gettext.Plural functions with unknown locales will result in a Gettext.Plural.UnknownLocaleError exception.Language and countryOften, a locale is composed as a language and country couple, such as en_US. The default implementation for Gettext.Plural handles xx_YY by forwarding it to xx (except for just Brazilian Portuguese, pt_BR, which is not forwarded to pt as pluralization rules slightly differ). We treat the underscore as a separator according to ISO 15897. Sometimes, a dash - is used as a separator (for example, en-US): this is not forwarded to en in the default Gettext.Plural (and it will raise an Gettext.Plural.UnknownLocaleError exception).ExamplesAn example of the plural form of a given number of elements in the Polish language:iex&gt; Plural.plural(&quot;pl&quot;, 1) 0 iex&gt; Plural.plural(&quot;pl&quot;, 2) 1 iex&gt; Plural.plural(&quot;pl&quot;, 5) 2 iex&gt; Plural.plural(&quot;pl&quot;, 112) 2As expected, nplurals/1 returns the possible number of plural forms:iex&gt; Plural.nplurals(&quot;pl&quot;) 3","ref":"Gettext.Plural.html","title":"Gettext.Plural","type":"behaviour"},{"doc":"","ref":"Gettext.Plural.html#nplurals/1","title":"Gettext.Plural.nplurals/1","type":"function"},{"doc":"Returns the number of possible plural forms in the given locale.","ref":"Gettext.Plural.html#c:nplurals/1","title":"Gettext.Plural.nplurals/1","type":"callback"},{"doc":"","ref":"Gettext.Plural.html#plural/2","title":"Gettext.Plural.plural/2","type":"function"},{"doc":"Returns the plural form in the given locale for the given count of elements.","ref":"Gettext.Plural.html#c:plural/2","title":"Gettext.Plural.plural/2","type":"callback"},{"doc":"Force Gettext modules to recompile once .po files change.","ref":"Mix.Tasks.Compile.Gettext.html","title":"Mix.Tasks.Compile.Gettext","type":"task"},{"doc":"","ref":"Mix.Tasks.Compile.Gettext.html#run/2","title":"Mix.Tasks.Compile.Gettext.run/2","type":"function"},{"doc":"Extracts translations by recompiling the Elixir source code.mix gettext.extract [OPTIONS]Translations are extracted into POT (Portable Object Template) files (with a .pot extension). The location of these files is determined by the :otp_app and :priv options given by Gettext modules when they call use Gettext. One POT file is generated for each translation domain.It is possible to give the --merge option to perform merging for every Gettext backend updated during merge:mix gettext.extract --mergeAll other options passed to gettext.extract are forwarded to the gettext.merge task (Mix.Tasks.Gettext.Merge), which is called internally by this task. For example:mix gettext.extract --merge --no-fuzzy","ref":"Mix.Tasks.Gettext.Extract.html","title":"Mix.Tasks.Gettext.Extract","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Gettext.Extract.html#run/1","title":"Mix.Tasks.Gettext.Extract.run/1","type":"function"},{"doc":"Merges PO/POT files with PO files.This task is used when translations in the source code change: when they do, mix gettext.extract is usually used to extract the new translations to POT files. At this point, developers or translators can use this task to &quot;sync&quot; the newly updated POT files with the existing locale-specific PO files. All the metadata for each translation (like position in the source code, comments and so on) is taken from the newly updated POT file; the only things taken from the PO file are the actual translated strings.Fuzzy matchingTranslations in the updated PO/POT file that have an exact match (a translation with the same msgid) in the old PO file are merged as described above. When a translation in the update PO/POT files has no match in the old PO file, a fuzzy match for that translation is attempted. For example, assume we have this POT file:msgid &quot;hello, world!&quot; msgstr &quot;&quot;and we merge it with this PO file:# notice no exclamation point here msgid &quot;hello, world&quot; msgstr &quot;ciao, mondo&quot;Since the two translations are very similar, the msgstr from the existing translation will be taken over to the new translation, which will however be marked as fuzzy:#, fuzzy msgid &quot;hello, world!&quot; msgstr &quot;ciao, mondo&quot;Generally, a fuzzy flag calls for review from a translator.Fuzzy matching can be configured (for example, the threshold for translation similarity can be tweaked) or disabled entirely; look at the &quot;Options&quot; section below.Usagemix gettext.merge OLD_FILE UPDATED_FILE [OPTIONS] mix gettext.merge DIR [OPTIONS]If two files are given as arguments, they must be a .po file and a .po/.pot file. The first one is the old PO file, while the second one is the last generated one. They are merged and written over the first file. For example:mix gettext.merge priv/gettext/en/LC_MESSAGES/default.po priv/gettext/default.potIf only one argument is given, then that argument must be a directory containing Gettext translations (with .pot files at the root level alongside locale directories - this is usually a &quot;backend&quot; directory used by a Gettext backend, see Gettext.Backend).mix gettext.merge priv/gettextIf the --locale LOCALE option is given, then only the PO files in DIR/LOCALE/LC_MESSAGES will be merged with the POT files in DIR. If no options are given, then all the PO files for all locales under DIR are merged with the POT files in DIR.Plural formsBy default, Gettext will determine the number of plural forms for newly generated translations by checking the value of nplurals in the Plural-Forms header in the existing .po file. If a .po file doesn't already exist and Gettext is creating a new one or if the Plural-Forms header is not in the .po file, Gettext will use the number of plural forms that Gettext.Plural returns for the locale of the file being created. The number of plural forms can be forced through the --plural-forms option (see below).Options--locale - a string representing a locale. If this is provided, then only the PO files in DIR/LOCALE/LC_MESSAGES will be merged with the POT files in DIR. This option can only be given when a single argument is passed to the task (a directory).--no-fuzzy - stops fuzzy matching from being performed when merging files.--fuzzy-threshold - a float between 0 and 1 which represents the miminum Jaro distance needed for two translations to be considered a fuzzy match. Overrides the global :fuzzy_threshold option (see the docs for Gettext for more information on this option).--plural-forms - a integer strictly greater than 0. If this is passed, new translations in the target PO files will have this number of empty plural forms. See the &quot;Plural forms&quot; section above.","ref":"Mix.Tasks.Gettext.Merge.html","title":"Mix.Tasks.Gettext.Merge","type":"task"},{"doc":"","ref":"Mix.Tasks.Gettext.Merge.html#locale_dir/2","title":"Mix.Tasks.Gettext.Merge.locale_dir/2","type":"function"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Gettext.Merge.html#run/1","title":"Mix.Tasks.Gettext.Merge.run/1","type":"function"},{"doc":"A generic error raised for a variety of possible Gettext-related reasons (for example, missing interpolation keys).","ref":"Gettext.Error.html","title":"Gettext.Error","type":"exception"},{"doc":"An error message raised for missing bindings errors.","ref":"Gettext.MissingBindingsError.html","title":"Gettext.MissingBindingsError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Gettext.MissingBindingsError.html#message/1","title":"Gettext.MissingBindingsError.message/1","type":"function"},{"doc":"","ref":"Gettext.MissingBindingsError.html#t:t/0","title":"Gettext.MissingBindingsError.t/0","type":"type"},{"doc":"An error raised when the syntax in a PO file (a file ending in .po) isn't correct.","ref":"Gettext.PO.SyntaxError.html","title":"Gettext.PO.SyntaxError","type":"exception"},{"doc":"Raised when a pluralized module doesn't know how to handle a locale.Examplesraise Gettext.Plural.UnknownLocaleError, &quot;en-US&quot;","ref":"Gettext.Plural.UnknownLocaleError.html","title":"Gettext.Plural.UnknownLocaleError","type":"exception"},{"doc":"","ref":"Gettext.PluralFormError.html","title":"Gettext.PluralFormError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Gettext.PluralFormError.html#message/1","title":"Gettext.PluralFormError.message/1","type":"function"},{"doc":"","ref":"Gettext.PluralFormError.html#t:t/0","title":"Gettext.PluralFormError.t/0","type":"type"}]